# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from limit import Gs2LimitRestClient, request as request_, result as result_
from limit.domain.iterator.namespaces import DescribeNamespacesIterator
from limit.domain.iterator.counters import DescribeCountersIterator
from limit.domain.iterator.counters_by_user_id import DescribeCountersByUserIdIterator
from limit.domain.iterator.limit_model_masters import DescribeLimitModelMastersIterator
from limit.domain.iterator.limit_models import DescribeLimitModelsIterator
from limit.domain.cache.namespace import NamespaceDomainCache
from limit.domain.cache.counter import CounterDomainCache
from limit.domain.cache.limit_model_master import LimitModelMasterDomainCache
from limit.domain.cache.limit_model import LimitModelDomainCache
from limit.domain.counter import CounterDomain
from limit.domain.counter_access_token import CounterAccessTokenDomain
from limit.domain.counter_access_token import CounterAccessTokenDomain


class UserDomain:
    _session: Gs2RestSession
    _client: Gs2LimitRestClient
    _namespace_name: str
    _user_id: str
    _counter_cache: CounterDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        user_id: str,
    ):
        self._session = session
        self._client = Gs2LimitRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._counter_cache = CounterDomainCache()

    def counters(
        self,
        limit_name: str,
    ) -> DescribeCountersByUserIdIterator:
        return DescribeCountersByUserIdIterator(
            self._counter_cache,
            self._client,
            self._namespace_name,
            self._user_id,
            limit_name,
        )

    def counter(
        self,
        limit_name: str,
        counter_name: str,
    ) -> CounterDomain:
        return CounterDomain(
            self._session,
            self._counter_cache,
            self._namespace_name,
            self._user_id,
            limit_name,
            counter_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from stamina.domain.service import *
from stamina.domain.namespace import *
from stamina.domain.stamina_model_master import *
from stamina.domain.max_stamina_table_master import *
from stamina.domain.recover_interval_table_master import *
from stamina.domain.recover_value_table_master import *
from stamina.domain.current_stamina_master import *
from stamina.domain.stamina_model import *
from stamina.domain.stamina import *
from stamina.domain.stamina_access_token import *
from stamina.domain.stamina import *
from stamina.domain.stamina_access_token import *
from stamina.domain.user import *
from stamina.domain.user_access_token import *
from stamina.domain.user import *
from stamina.domain.user_access_token import *
from stamina.domain.iterator.namespaces import *
from stamina.domain.iterator.stamina_model_masters import *
from stamina.domain.iterator.max_stamina_table_masters import *
from stamina.domain.iterator.recover_interval_table_masters import *
from stamina.domain.iterator.recover_value_table_masters import *
from stamina.domain.iterator.stamina_models import *
from stamina.domain.iterator.staminas import *
from stamina.domain.iterator.staminas_by_user_id import *
from stamina.domain.cache.namespace import *
from stamina.domain.cache.stamina_model_master import *
from stamina.domain.cache.max_stamina_table_master import *
from stamina.domain.cache.recover_interval_table_master import *
from stamina.domain.cache.recover_value_table_master import *
from stamina.domain.cache.stamina_model import *
from stamina.domain.cache.stamina import *


# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from account import Gs2AccountRestClient, request as request_, result as result_
from account.domain.iterator.namespaces import DescribeNamespacesIterator
from account.domain.iterator.accounts import DescribeAccountsIterator
from account.domain.iterator.take_overs import DescribeTakeOversIterator
from account.domain.iterator.take_overs_by_user_id import DescribeTakeOversByUserIdIterator
from account.domain.cache.namespace import NamespaceDomainCache
from account.domain.cache.account import AccountDomainCache
from account.domain.cache.take_over import TakeOverDomainCache
from account.domain.take_over import TakeOverDomain
from account.domain.take_over_access_token import TakeOverAccessTokenDomain
from account.domain.take_over_access_token import TakeOverAccessTokenDomain


class AccountDomain:
    _session: Gs2RestSession
    _client: Gs2AccountRestClient
    _account_cache: AccountDomainCache
    _namespace_name: str
    _user_id: str
    _take_over_cache: TakeOverDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        account_cache: AccountDomainCache,
        namespace_name: str,
        user_id: str,
    ):
        self._session = session
        self._client = Gs2AccountRestClient(
            session,
        )
        self._account_cache = account_cache
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._take_over_cache = TakeOverDomainCache()

    def update_time_offset(
        self,
        request: request_.UpdateTimeOffsetRequest,
    ) -> result_.UpdateTimeOffsetResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.update_time_offset(
            request,
        )
        self._account_cache.update(r.item)
        return r

    def load(
        self,
        request: request_.GetAccountRequest,
    ) -> result_.GetAccountResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.get_account(
            request,
        )
        self._account_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteAccountRequest,
    ) -> result_.DeleteAccountResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.delete_account(
            request,
        )
        self._account_cache.delete(r.item)
        return r

    def authentication(
        self,
        request: request_.AuthenticationRequest,
    ) -> result_.AuthenticationResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.authentication(
            request,
        )
        self._account_cache.update(r.item)
        return r

    def create_take_over(
        self,
        request: request_.CreateTakeOverByUserIdRequest,
    ) -> result_.CreateTakeOverByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.create_take_over_by_user_id(
            request,
        )
        return r

    def take_overs(
        self,
    ) -> DescribeTakeOversByUserIdIterator:
        return DescribeTakeOversByUserIdIterator(
            self._take_over_cache,
            self._client,
            self._namespace_name,
            self._user_id,
        )

    def take_over(
        self,
        type_: int,
    ) -> TakeOverDomain:
        return TakeOverDomain(
            self._session,
            self._take_over_cache,
            self._namespace_name,
            self._user_id,
            type_,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from exchange import Gs2ExchangeRestClient, request as request_, result as result_
from exchange.domain.iterator.namespaces import DescribeNamespacesIterator
from exchange.domain.iterator.rate_models import DescribeRateModelsIterator
from exchange.domain.iterator.rate_model_masters import DescribeRateModelMastersIterator
from exchange.domain.iterator.awaits import DescribeAwaitsIterator
from exchange.domain.iterator.awaits_by_user_id import DescribeAwaitsByUserIdIterator
from exchange.domain.cache.namespace import NamespaceDomainCache
from exchange.domain.cache.rate_model import RateModelDomainCache
from exchange.domain.cache.rate_model_master import RateModelMasterDomainCache
from exchange.domain.cache.await_ import AwaitDomainCache


class AwaitAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2ExchangeRestClient
    _await_cache: AwaitDomainCache
    _namespace_name: str
    _access_token: AccessToken
    _await_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        await_cache: AwaitDomainCache,
        namespace_name: str,
        access_token: AccessToken,
        await_name: str,
    ):
        self._session = session
        self._client = Gs2ExchangeRestClient(
            session,
        )
        self._await_cache = await_cache
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._await_name = await_name

    def load(
        self,
        request: request_.GetAwaitRequest,
    ) -> result_.GetAwaitResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_await_name(self._await_name)
        r = self._client.get_await(
            request,
        )
        self._await_cache.update(r.item)
        return r

    def acquire(
        self,
        request: request_.AcquireRequest,
    ) -> result_.AcquireResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_await_name(self._await_name)
        r = self._client.acquire(
            request,
        )
        self._await_cache.update(r.item)
        return r

    def skip(
        self,
        request: request_.SkipRequest,
    ) -> result_.SkipResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_await_name(self._await_name)
        r = self._client.skip(
            request,
        )
        self._await_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteAwaitRequest,
    ) -> result_.DeleteAwaitResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_await_name(self._await_name)
        r = self._client.delete_await(
            request,
        )
        self._await_cache.delete(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from formation import Gs2FormationRestClient, request as request_, result as result_
from formation.domain.iterator.namespaces import DescribeNamespacesIterator
from formation.domain.iterator.form_model_masters import DescribeFormModelMastersIterator
from formation.domain.iterator.mold_models import DescribeMoldModelsIterator
from formation.domain.iterator.mold_model_masters import DescribeMoldModelMastersIterator
from formation.domain.iterator.molds import DescribeMoldsIterator
from formation.domain.iterator.molds_by_user_id import DescribeMoldsByUserIdIterator
from formation.domain.iterator.forms import DescribeFormsIterator
from formation.domain.iterator.forms_by_user_id import DescribeFormsByUserIdIterator
from formation.domain.cache.namespace import NamespaceDomainCache
from formation.domain.cache.form_model_master import FormModelMasterDomainCache
from formation.domain.cache.mold_model import MoldModelDomainCache
from formation.domain.cache.mold_model_master import MoldModelMasterDomainCache
from formation.domain.cache.mold import MoldDomainCache
from formation.domain.cache.form import FormDomainCache


class FormDomain:
    _session: Gs2RestSession
    _client: Gs2FormationRestClient
    _form_cache: FormDomainCache
    _namespace_name: str
    _user_id: str
    _mold_name: str
    _index: int

    def __init__(
        self,
        session: Gs2RestSession,
        form_cache: FormDomainCache,
        namespace_name: str,
        user_id: str,
        mold_name: str,
        index: int,
    ):
        self._session = session
        self._client = Gs2FormationRestClient(
            session,
        )
        self._form_cache = form_cache
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._mold_name = mold_name
        self._index = index

    def load(
        self,
        request: request_.GetFormByUserIdRequest,
    ) -> result_.GetFormByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_mold_name(self._mold_name)
        request.with_index(self._index)
        r = self._client.get_form_by_user_id(
            request,
        )
        self._form_cache.update(r.item)
        return r

    def get_with_signature(
        self,
        request: request_.GetFormWithSignatureByUserIdRequest,
    ) -> result_.GetFormWithSignatureByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_mold_name(self._mold_name)
        request.with_index(self._index)
        r = self._client.get_form_with_signature_by_user_id(
            request,
        )
        self._form_cache.update(r.item)
        return r

    def set(
        self,
        request: request_.SetFormByUserIdRequest,
    ) -> result_.SetFormByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_mold_name(self._mold_name)
        request.with_index(self._index)
        r = self._client.set_form_by_user_id(
            request,
        )
        self._form_cache.update(r.item)
        return r

    def acquire_actions_to_properties(
        self,
        request: request_.AcquireActionsToFormPropertiesRequest,
    ) -> result_.AcquireActionsToFormPropertiesResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_mold_name(self._mold_name)
        request.with_index(self._index)
        r = self._client.acquire_actions_to_form_properties(
            request,
        )
        self._form_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteFormByUserIdRequest,
    ) -> result_.DeleteFormByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_mold_name(self._mold_name)
        request.with_index(self._index)
        r = self._client.delete_form_by_user_id(
            request,
        )
        self._form_cache.delete(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from quest import Gs2QuestRestClient, request as request_, result as result_
from quest.domain.iterator.namespaces import DescribeNamespacesIterator
from quest.domain.iterator.quest_group_model_masters import DescribeQuestGroupModelMastersIterator
from quest.domain.iterator.quest_model_masters import DescribeQuestModelMastersIterator
from quest.domain.iterator.progresses_by_user_id import DescribeProgressesByUserIdIterator
from quest.domain.iterator.completed_quest_lists import DescribeCompletedQuestListsIterator
from quest.domain.iterator.completed_quest_lists_by_user_id import DescribeCompletedQuestListsByUserIdIterator
from quest.domain.iterator.quest_group_models import DescribeQuestGroupModelsIterator
from quest.domain.iterator.quest_models import DescribeQuestModelsIterator
from quest.domain.cache.namespace import NamespaceDomainCache
from quest.domain.cache.quest_group_model_master import QuestGroupModelMasterDomainCache
from quest.domain.cache.quest_model_master import QuestModelMasterDomainCache
from quest.domain.cache.progress import ProgressDomainCache
from quest.domain.cache.completed_quest_list import CompletedQuestListDomainCache
from quest.domain.cache.quest_group_model import QuestGroupModelDomainCache
from quest.domain.cache.quest_model import QuestModelDomainCache
from quest.domain.quest_model_master import QuestModelMasterDomain


class QuestGroupModelMasterDomain:
    _session: Gs2RestSession
    _client: Gs2QuestRestClient
    _quest_group_model_master_cache: QuestGroupModelMasterDomainCache
    _namespace_name: str
    _quest_group_name: str
    _quest_model_master_cache: QuestModelMasterDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        quest_group_model_master_cache: QuestGroupModelMasterDomainCache,
        namespace_name: str,
        quest_group_name: str,
    ):
        self._session = session
        self._client = Gs2QuestRestClient(
            session,
        )
        self._quest_group_model_master_cache = quest_group_model_master_cache
        self._namespace_name = namespace_name
        self._quest_group_name = quest_group_name
        self._quest_model_master_cache = QuestModelMasterDomainCache()

    def load(
        self,
        request: request_.GetQuestGroupModelMasterRequest,
    ) -> result_.GetQuestGroupModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_quest_group_name(self._quest_group_name)
        r = self._client.get_quest_group_model_master(
            request,
        )
        self._quest_group_model_master_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateQuestGroupModelMasterRequest,
    ) -> result_.UpdateQuestGroupModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_quest_group_name(self._quest_group_name)
        r = self._client.update_quest_group_model_master(
            request,
        )
        self._quest_group_model_master_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteQuestGroupModelMasterRequest,
    ) -> result_.DeleteQuestGroupModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_quest_group_name(self._quest_group_name)
        r = self._client.delete_quest_group_model_master(
            request,
        )
        self._quest_group_model_master_cache.delete(r.item)
        return r

    def create_quest_model_master(
        self,
        request: request_.CreateQuestModelMasterRequest,
    ) -> result_.CreateQuestModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_quest_group_name(self._quest_group_name)
        r = self._client.create_quest_model_master(
            request,
        )
        return r

    def quest_model_masters(
        self,
    ) -> DescribeQuestModelMastersIterator:
        return DescribeQuestModelMastersIterator(
            self._quest_model_master_cache,
            self._client,
            self._namespace_name,
            self._quest_group_name,
        )

    def quest_model_master(
        self,
        quest_name: str,
    ) -> QuestModelMasterDomain:
        return QuestModelMasterDomain(
            self._session,
            self._quest_model_master_cache,
            self._namespace_name,
            self._quest_group_name,
            quest_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from friend.domain.service import *
from friend.domain.namespace import *
from friend.domain.user import *
from friend.domain.user_access_token import *
from friend.domain.user import *
from friend.domain.user_access_token import *
from friend.domain.profile import *
from friend.domain.profile_access_token import *
from friend.domain.profile import *
from friend.domain.profile_access_token import *
from friend.domain.follow import *
from friend.domain.follow_access_token import *
from friend.domain.follow import *
from friend.domain.follow_access_token import *
from friend.domain.friend import *
from friend.domain.friend_access_token import *
from friend.domain.friend import *
from friend.domain.friend_access_token import *
from friend.domain.send_box import *
from friend.domain.send_box_access_token import *
from friend.domain.send_box import *
from friend.domain.send_box_access_token import *
from friend.domain.inbox import *
from friend.domain.inbox_access_token import *
from friend.domain.inbox import *
from friend.domain.inbox_access_token import *
from friend.domain.black_list import *
from friend.domain.black_list_access_token import *
from friend.domain.black_list import *
from friend.domain.black_list_access_token import *
from friend.domain.user import *
from friend.domain.user_access_token import *
from friend.domain.user import *
from friend.domain.user_access_token import *
from friend.domain.iterator.namespaces import *
from friend.domain.iterator.follows import *
from friend.domain.iterator.follows_by_user_id import *
from friend.domain.iterator.friends import *
from friend.domain.iterator.friends_by_user_id import *
from friend.domain.iterator.send_requests import *
from friend.domain.iterator.send_requests_by_user_id import *
from friend.domain.iterator.receive_requests import *
from friend.domain.iterator.receive_requests_by_user_id import *
from friend.domain.iterator.black_list import *
from friend.domain.iterator.black_list_by_user_id import *
from friend.domain.cache.namespace import *
from friend.domain.cache.follow_user import *
from friend.domain.cache.friend_user import *
from friend.domain.cache.friend_request import *


# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from dictionary import Gs2DictionaryRestClient, request as request_, result as result_
from dictionary.domain.iterator.namespaces import DescribeNamespacesIterator
from dictionary.domain.iterator.entry_models import DescribeEntryModelsIterator
from dictionary.domain.iterator.entry_model_masters import DescribeEntryModelMastersIterator
from dictionary.domain.iterator.entries import DescribeEntriesIterator
from dictionary.domain.iterator.entries_by_user_id import DescribeEntriesByUserIdIterator
from dictionary.domain.cache.namespace import NamespaceDomainCache
from dictionary.domain.cache.entry_model import EntryModelDomainCache
from dictionary.domain.cache.entry_model_master import EntryModelMasterDomainCache
from dictionary.domain.cache.entry import EntryDomainCache
from dictionary.domain.entry import EntryDomain
from dictionary.domain.entry_access_token import EntryAccessTokenDomain
from dictionary.domain.entry_access_token import EntryAccessTokenDomain


class UserAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2DictionaryRestClient
    _namespace_name: str
    _access_token: AccessToken
    _entry_cache: EntryDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
    ):
        self._session = session
        self._client = Gs2DictionaryRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._entry_cache = EntryDomainCache()

    def entries(
        self,
    ) -> DescribeEntriesIterator:
        return DescribeEntriesIterator(
            self._entry_cache,
            self._client,
            self._namespace_name,
            self._access_token,
        )

    def entry(
        self,
        entry_model_name: str,
    ) -> EntryAccessTokenDomain:
        return EntryAccessTokenDomain(
            self._session,
            self._entry_cache,
            self._namespace_name,
            self._access_token,
            entry_model_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from inventory.domain.service import *
from inventory.domain.namespace import *
from inventory.domain.inventory_model_master import *
from inventory.domain.inventory_model import *
from inventory.domain.item_model_master import *
from inventory.domain.item_model import *
from inventory.domain.current_item_model_master import *
from inventory.domain.inventory import *
from inventory.domain.inventory_access_token import *
from inventory.domain.inventory import *
from inventory.domain.inventory_access_token import *
from inventory.domain.item_set import *
from inventory.domain.item_set_access_token import *
from inventory.domain.item_set import *
from inventory.domain.item_set_access_token import *
from inventory.domain.reference_of import *
from inventory.domain.reference_of_access_token import *
from inventory.domain.reference_of import *
from inventory.domain.reference_of_access_token import *
from inventory.domain.user import *
from inventory.domain.user_access_token import *
from inventory.domain.user import *
from inventory.domain.user_access_token import *
from inventory.domain.iterator.namespaces import *
from inventory.domain.iterator.inventory_model_masters import *
from inventory.domain.iterator.inventory_models import *
from inventory.domain.iterator.item_model_masters import *
from inventory.domain.iterator.item_models import *
from inventory.domain.iterator.inventories import *
from inventory.domain.iterator.inventories_by_user_id import *
from inventory.domain.iterator.item_sets import *
from inventory.domain.iterator.item_sets_by_user_id import *
from inventory.domain.iterator.reference_of import *
from inventory.domain.iterator.reference_of_by_user_id import *
from inventory.domain.cache.namespace import *
from inventory.domain.cache.inventory_model_master import *
from inventory.domain.cache.inventory_model import *
from inventory.domain.cache.item_model_master import *
from inventory.domain.cache.item_model import *
from inventory.domain.cache.inventory import *
from inventory.domain.cache.item_set import *


# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from lottery import Gs2LotteryRestClient, request as request_, result as result_
from lottery.domain.iterator.namespaces import DescribeNamespacesIterator
from lottery.domain.iterator.lottery_model_masters import DescribeLotteryModelMastersIterator
from lottery.domain.iterator.prize_table_masters import DescribePrizeTableMastersIterator
from lottery.domain.iterator.boxes import DescribeBoxesIterator
from lottery.domain.iterator.boxes_by_user_id import DescribeBoxesByUserIdIterator
from lottery.domain.iterator.lottery_models import DescribeLotteryModelsIterator
from lottery.domain.iterator.prize_tables import DescribePrizeTablesIterator
from lottery.domain.iterator.probabilities import DescribeProbabilitiesIterator
from lottery.domain.iterator.probabilities_by_user_id import DescribeProbabilitiesByUserIdIterator
from lottery.domain.cache.namespace import NamespaceDomainCache
from lottery.domain.cache.lottery_model_master import LotteryModelMasterDomainCache
from lottery.domain.cache.prize_table_master import PrizeTableMasterDomainCache
from lottery.domain.cache.box import BoxDomainCache
from lottery.domain.cache.lottery_model import LotteryModelDomainCache
from lottery.domain.cache.prize_table import PrizeTableDomainCache
from lottery.domain.cache.probability import ProbabilityDomainCache


class LotteryModelMasterDomain:
    _session: Gs2RestSession
    _client: Gs2LotteryRestClient
    _lottery_model_master_cache: LotteryModelMasterDomainCache
    _namespace_name: str
    _lottery_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        lottery_model_master_cache: LotteryModelMasterDomainCache,
        namespace_name: str,
        lottery_name: str,
    ):
        self._session = session
        self._client = Gs2LotteryRestClient(
            session,
        )
        self._lottery_model_master_cache = lottery_model_master_cache
        self._namespace_name = namespace_name
        self._lottery_name = lottery_name

    def load(
        self,
        request: request_.GetLotteryModelMasterRequest,
    ) -> result_.GetLotteryModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_lottery_name(self._lottery_name)
        r = self._client.get_lottery_model_master(
            request,
        )
        self._lottery_model_master_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateLotteryModelMasterRequest,
    ) -> result_.UpdateLotteryModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_lottery_name(self._lottery_name)
        r = self._client.update_lottery_model_master(
            request,
        )
        self._lottery_model_master_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteLotteryModelMasterRequest,
    ) -> result_.DeleteLotteryModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_lottery_name(self._lottery_name)
        r = self._client.delete_lottery_model_master(
            request,
        )
        self._lottery_model_master_cache.delete(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from enhance import Gs2EnhanceRestClient, request as request_, result as result_
from enhance.domain.iterator.namespaces import DescribeNamespacesIterator
from enhance.domain.iterator.rate_models import DescribeRateModelsIterator
from enhance.domain.iterator.rate_model_masters import DescribeRateModelMastersIterator
from enhance.domain.iterator.progresses_by_user_id import DescribeProgressesByUserIdIterator
from enhance.domain.cache.namespace import NamespaceDomainCache
from enhance.domain.cache.rate_model import RateModelDomainCache
from enhance.domain.cache.rate_model_master import RateModelMasterDomainCache
from enhance.domain.cache.progress import ProgressDomainCache
from enhance.domain.progress import ProgressDomain
from enhance.domain.progress_access_token import ProgressAccessTokenDomain


class UserDomain:
    _session: Gs2RestSession
    _client: Gs2EnhanceRestClient
    _namespace_name: str
    _user_id: str
    _progress_cache: ProgressDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        user_id: str,
    ):
        self._session = session
        self._client = Gs2EnhanceRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._progress_cache = ProgressDomainCache()

    def direct_enhance(
        self,
        request: request_.DirectEnhanceByUserIdRequest,
    ) -> result_.DirectEnhanceByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.direct_enhance_by_user_id(
            request,
        )
        return r

    def create_progress(
        self,
        request: request_.CreateProgressByUserIdRequest,
    ) -> result_.CreateProgressByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.create_progress_by_user_id(
            request,
        )
        return r

    def start(
        self,
        request: request_.StartByUserIdRequest,
    ) -> result_.StartByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.start_by_user_id(
            request,
        )
        return r

    def end(
        self,
        request: request_.EndByUserIdRequest,
    ) -> result_.EndByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.end_by_user_id(
            request,
        )
        return r

    def delete_progress(
        self,
        request: request_.DeleteProgressByUserIdRequest,
    ) -> result_.DeleteProgressByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.delete_progress_by_user_id(
            request,
        )
        return r

    def progress(
        self,
    ) -> ProgressDomain:
        return ProgressDomain(
            self._session,
            self._progress_cache,
            self._namespace_name,
            self._user_id,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from experience import Gs2ExperienceRestClient, request as request_, result as result_
from experience.domain.iterator.namespaces import DescribeNamespacesIterator
from experience.domain.iterator.experience_model_masters import DescribeExperienceModelMastersIterator
from experience.domain.iterator.experience_models import DescribeExperienceModelsIterator
from experience.domain.iterator.threshold_masters import DescribeThresholdMastersIterator
from experience.domain.iterator.statuses import DescribeStatusesIterator
from experience.domain.iterator.statuses_by_user_id import DescribeStatusesByUserIdIterator
from experience.domain.cache.namespace import NamespaceDomainCache
from experience.domain.cache.experience_model_master import ExperienceModelMasterDomainCache
from experience.domain.cache.experience_model import ExperienceModelDomainCache
from experience.domain.cache.threshold_master import ThresholdMasterDomainCache
from experience.domain.cache.status import StatusDomainCache
from experience.domain.current_experience_master import CurrentExperienceMasterDomain
from experience.domain.experience_model import ExperienceModelDomain
from experience.domain.user import UserDomain
from experience.domain.user_access_token import UserAccessTokenDomain
from experience.domain.user_access_token import UserAccessTokenDomain
from experience.domain.threshold_master import ThresholdMasterDomain
from experience.domain.experience_model_master import ExperienceModelMasterDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2ExperienceRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _experience_model_master_cache: ExperienceModelMasterDomainCache
    _experience_model_cache: ExperienceModelDomainCache
    _threshold_master_cache: ThresholdMasterDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2ExperienceRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._experience_model_master_cache = ExperienceModelMasterDomainCache()
        self._experience_model_cache = ExperienceModelDomainCache()
        self._threshold_master_cache = ThresholdMasterDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_experience_model_master(
        self,
        request: request_.CreateExperienceModelMasterRequest,
    ) -> result_.CreateExperienceModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_experience_model_master(
            request,
        )
        return r

    def create_threshold_master(
        self,
        request: request_.CreateThresholdMasterRequest,
    ) -> result_.CreateThresholdMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_threshold_master(
            request,
        )
        return r

    def experience_model_masters(
        self,
    ) -> DescribeExperienceModelMastersIterator:
        return DescribeExperienceModelMastersIterator(
            self._experience_model_master_cache,
            self._client,
            self._namespace_name,
        )

    def experience_models(
        self,
    ) -> DescribeExperienceModelsIterator:
        return DescribeExperienceModelsIterator(
            self._experience_model_cache,
            self._client,
            self._namespace_name,
        )

    def threshold_masters(
        self,
    ) -> DescribeThresholdMastersIterator:
        return DescribeThresholdMastersIterator(
            self._threshold_master_cache,
            self._client,
            self._namespace_name,
        )

    def current_experience_master(
        self,
    ) -> CurrentExperienceMasterDomain:
        return CurrentExperienceMasterDomain(
            self._session,
            self._namespace_name,
        )

    def experience_model(
        self,
        experience_name: str,
    ) -> ExperienceModelDomain:
        return ExperienceModelDomain(
            self._session,
            self._experience_model_cache,
            self._namespace_name,
            experience_name,
        )

    def user(
        self,
        user_id: str,
    ) -> UserDomain:
        return UserDomain(
            self._session,
            self._namespace_name,
            user_id,
        )

    def access_token(
        self,
        access_token: AccessToken,
    ) -> UserAccessTokenDomain:
        return UserAccessTokenDomain(
            self._session,
            self._namespace_name,
            access_token,
        )

    def threshold_master(
        self,
        threshold_name: str,
    ) -> ThresholdMasterDomain:
        return ThresholdMasterDomain(
            self._session,
            self._threshold_master_cache,
            self._namespace_name,
            threshold_name,
        )

    def experience_model_master(
        self,
        experience_name: str,
    ) -> ExperienceModelMasterDomain:
        return ExperienceModelMasterDomain(
            self._session,
            self._experience_model_master_cache,
            self._namespace_name,
            experience_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from key import Gs2KeyRestClient, request as request_, result as result_
from key.domain.iterator.namespaces import DescribeNamespacesIterator
from key.domain.iterator.keys import DescribeKeysIterator
from key.domain.iterator.git_hub_api_keys import DescribeGitHubApiKeysIterator
from key.domain.cache.namespace import NamespaceDomainCache
from key.domain.cache.key import KeyDomainCache
from key.domain.cache.git_hub_api_key import GitHubApiKeyDomainCache
from key.domain.key import KeyDomain
from key.domain.git_hub_api_key import GitHubApiKeyDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2KeyRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _key_cache: KeyDomainCache
    _git_hub_api_key_cache: GitHubApiKeyDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2KeyRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._key_cache = KeyDomainCache()
        self._git_hub_api_key_cache = GitHubApiKeyDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_key(
        self,
        request: request_.CreateKeyRequest,
    ) -> result_.CreateKeyResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_key(
            request,
        )
        return r

    def create_git_hub_api_key(
        self,
        request: request_.CreateGitHubApiKeyRequest,
    ) -> result_.CreateGitHubApiKeyResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_git_hub_api_key(
            request,
        )
        return r

    def keys(
        self,
    ) -> DescribeKeysIterator:
        return DescribeKeysIterator(
            self._key_cache,
            self._client,
            self._namespace_name,
        )

    def git_hub_api_keys(
        self,
    ) -> DescribeGitHubApiKeysIterator:
        return DescribeGitHubApiKeysIterator(
            self._git_hub_api_key_cache,
            self._client,
            self._namespace_name,
        )

    def key(
        self,
        key_name: str,
    ) -> KeyDomain:
        return KeyDomain(
            self._session,
            self._key_cache,
            self._namespace_name,
            key_name,
        )

    def git_hub_api_key(
        self,
        api_key_name: str,
    ) -> GitHubApiKeyDomain:
        return GitHubApiKeyDomain(
            self._session,
            self._git_hub_api_key_cache,
            self._namespace_name,
            api_key_name,
        )
